<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de" sourcelanguage="en">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../../about.ui" line="14"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="48"/>
        <source>Lightweight file manager</source>
        <translation>Ressourcen schonender Dateimanager</translation>
    </message>
    <message>
        <source>PCMan File Manager

Copyright (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation type="vanished">PCMan File Manager

Copyright (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

Dieses Programm ist freie Software. Sie können es unter den Bedingungen der GNU General Public License, wie von der Free Software Foundation veröffentlicht, weitergeben und/oder modifizieren, entweder gemäß Version 2 der Lizenz oder (nach Ihrer Option) jeder späteren Version.

Die Veröffentlichung dieses Programms erfolgt in der Hoffnung, daß es Ihnen von Nutzen sein wird, aber OHNE IRGENDEINE GARANTIE, sogar ohne die implizite Garantie der MARKTREIFE oder der VERWENDBARKEIT FÜR EINEN BESTIMMTEN ZWECK. Details finden Sie in der GNU General Public License.

Sie sollten ein Exemplar der GNU General Public License zusammen mit diesem Programm erhalten haben. Falls nicht, schreiben Sie an die Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA.</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="87"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</source>
        <translation>Programmierung:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="58"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://lxqt.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://lxqt.org/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://lxqt.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://lxqt.org/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="25"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM-Qt&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../about.ui" line="78"/>
        <source>Authors</source>
        <translation>Autoren</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="100"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="109"/>
        <source>PCManFM-Qt File Manager

Copyright (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoRunDialog</name>
    <message>
        <location filename="../../autorun.ui" line="14"/>
        <source>Removable medium is inserted</source>
        <translation>Ein entfernbares Speichermedium wurde eingelegt</translation>
    </message>
    <message>
        <location filename="../../autorun.ui" line="33"/>
        <source>&lt;b&gt;Removable medium is inserted&lt;/b&gt;</source>
        <translation>&lt;b&gt;Ein entfernbares Speichermedium wurde eingelegt&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../autorun.ui" line="40"/>
        <source>Type of medium:</source>
        <translation>Art des Mediums:</translation>
    </message>
    <message>
        <location filename="../../autorun.ui" line="47"/>
        <source>Detecting...</source>
        <translation>Erkennungsvorgang...</translation>
    </message>
    <message>
        <location filename="../../autorun.ui" line="56"/>
        <source>Please select the action you want to perform:</source>
        <translation>Bitte wählen Sie die Handlung, welche Sie ausführen möchten:</translation>
    </message>
</context>
<context>
    <name>ConnectServerDialog</name>
    <message>
        <location filename="../../connect.ui" line="14"/>
        <source>Connect to remote server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="23"/>
        <source>Anonymous &amp;login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="36"/>
        <source>Login as &amp;user:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="65"/>
        <source>Specify remote folder to connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="72"/>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="79"/>
        <source>Port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="86"/>
        <source>Path:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="96"/>
        <source>Host:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DesktopFolder</name>
    <message>
        <location filename="../../desktop-folder.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-folder.ui" line="23"/>
        <source>Desktop</source>
        <translation>Schreibtisch</translation>
    </message>
    <message>
        <location filename="../../desktop-folder.ui" line="29"/>
        <source>Desktop folder:</source>
        <translation>Schreibtischordner:</translation>
    </message>
    <message>
        <location filename="../../desktop-folder.ui" line="36"/>
        <source>Image file</source>
        <translation>Bilddatei</translation>
    </message>
    <message>
        <location filename="../../desktop-folder.ui" line="42"/>
        <source>Folder path</source>
        <translation>Pfad des Ordners</translation>
    </message>
    <message>
        <location filename="../../desktop-folder.ui" line="49"/>
        <source>&amp;Browse</source>
        <translation>&amp;Suchen</translation>
    </message>
</context>
<context>
    <name>DesktopPreferencesDialog</name>
    <message>
        <location filename="../../desktop-preferences.ui" line="14"/>
        <source>Desktop Preferences</source>
        <translation>Schreibtischeinstellungen</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="30"/>
        <source>Background</source>
        <translation>Hintergrund</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="52"/>
        <source>Wallpaper mode:</source>
        <translation>Hintergrundbildmodus:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="65"/>
        <source>Wallpaper image file:</source>
        <translation>Hintergrundbild:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="85"/>
        <source>Select background color:</source>
        <translation>Hintergrundfarbe:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="94"/>
        <source>Image file</source>
        <translation>Bilddatei</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="100"/>
        <source>Image file path</source>
        <translation>Pfad zur Bilddatei</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="107"/>
        <source>&amp;Browse</source>
        <translation>&amp;Suchen</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="119"/>
        <source>Icons</source>
        <translation>Symbole</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="125"/>
        <source>Icon size:</source>
        <translation>Symbolgröße:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="138"/>
        <source>Label Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="176"/>
        <source>Select  text color:</source>
        <translation>Farbe der Beschriftung:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="189"/>
        <source>Select shadow color:</source>
        <translation>Farbe des Schattens:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="202"/>
        <source>Select font:</source>
        <translation>Schrift für Beschriftung:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="24"/>
        <source>General</source>
        <translation>Allgemeines</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="225"/>
        <source>Spacing</source>
        <translation>Abstand</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="231"/>
        <source>Minimum item margins:</source>
        <translation>Minimaler Rand der Objekte:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="238"/>
        <source>3 px by default.</source>
        <translation>Standardwert 3 px.</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="241"/>
        <location filename="../../desktop-preferences.ui" line="265"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="254"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="261"/>
        <source>1 px by default.
A space is also reserved for 3 lines of text.</source>
        <translation>Standardwert 1 px.
Zusätzlich wird ein 3 Textzeilen entsprechender Abstand freigehalten.</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="278"/>
        <source>Lock</source>
        <translation>Sperren (vertikaler Abstand = horizontaler Abstand)</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="315"/>
        <source>Slide Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="321"/>
        <source>Enable Slide Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="333"/>
        <source>Wallpaper image folder:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="340"/>
        <source>Browse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="347"/>
        <source> hour(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="357"/>
        <source>and</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="370"/>
        <source>Intervals less than 5min will be ignored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="373"/>
        <source>Interval:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="380"/>
        <source> minute(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="406"/>
        <source>Wallpaper folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="429"/>
        <source>Randomize the slide show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="459"/>
        <source>Window Manager</source>
        <translation>Fenstermanager</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="465"/>
        <source>Show menus provided by window managers when desktop is clicked</source>
        <translation>Beim Klicken auf den Schreibtisch die Menüs des Fenstermanagers anzeigen</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translatorcomment>not an ideal translation, see discussion in https://github.com/lxde/lxqt/issues/699</translatorcomment>
        <translation type="vanished">Schreibtisch</translation>
    </message>
    <message>
        <source>Desktop folder:</source>
        <translation type="vanished">Schreibtischordner:</translation>
    </message>
    <message>
        <source>Folder path</source>
        <translation type="vanished">Pfad des Ordners</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="453"/>
        <source>Advanced</source>
        <translation>Erweitert</translation>
    </message>
</context>
<context>
    <name>FindFilesDialog</name>
    <message>
        <source>Find Files</source>
        <translation type="vanished">Dateisuche</translation>
    </message>
    <message>
        <source>Name/Location</source>
        <translation type="vanished">Dateiname, Lokalisation</translation>
    </message>
    <message>
        <source>File name patterns</source>
        <translation type="vanished">Dateiname</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation type="vanished">Suchmuster:</translation>
    </message>
    <message>
        <source>Case insensitive</source>
        <translation type="vanished">Groß- und Kleinschreibung ignorieren</translation>
    </message>
    <message>
        <source>Use regular expression</source>
        <translation type="vanished">Muster ist regulärer Ausdruck</translation>
    </message>
    <message>
        <source>Places to search</source>
        <translation type="vanished">Lokalisation</translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="vanished">Hinzufügen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="vanished">Entfernen</translation>
    </message>
    <message>
        <source>Search in sub directories</source>
        <translation type="vanished">Unterverzeichnisse einbeziehen</translation>
    </message>
    <message>
        <source>Search hidden files</source>
        <translation type="vanished">versteckte Dateien einbeziehen</translation>
    </message>
    <message>
        <source>File Type</source>
        <translation type="vanished">Dateityp</translation>
    </message>
    <message>
        <source>Only search for files of following types:</source>
        <translation type="vanished">Suche auf die folgenden Typen beschränken:</translation>
    </message>
    <message>
        <source>Text files</source>
        <translation type="vanished">Textdateien</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation type="vanished">Bilddateien</translation>
    </message>
    <message>
        <source>Audio files</source>
        <translation type="vanished">Audiodateien</translation>
    </message>
    <message>
        <source>Video files</source>
        <translation type="vanished">Videodateien</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="vanished">Dokumente</translation>
    </message>
    <message>
        <source>Content</source>
        <translation type="vanished">Inhalt</translation>
    </message>
    <message>
        <source>File contains</source>
        <translation type="vanished">Datei enthält</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation type="vanished">Dateieigenschaften</translation>
    </message>
    <message>
        <source>File Size</source>
        <translation type="vanished">Dateigröße</translation>
    </message>
    <message>
        <source>Bigger than:</source>
        <translation type="vanished">größer als:</translation>
    </message>
    <message>
        <source>Smaller than:</source>
        <translation type="vanished">kleiner als:</translation>
    </message>
    <message>
        <source>Last Modified Time</source>
        <translation type="vanished">Zeitpunkt der letzten Modifikation</translation>
    </message>
    <message>
        <source>Earlier than:</source>
        <translation type="vanished">vor:</translation>
    </message>
    <message>
        <source>Later than:</source>
        <translation type="vanished">nach:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../main-win.ui" line="14"/>
        <source>File Manager</source>
        <translation>Dateimanager</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="293"/>
        <source>Go Up</source>
        <translation>Hoch</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="296"/>
        <source>Alt+Up</source>
        <translation>Alt+Bild hoch</translation>
    </message>
    <message>
        <source>Home</source>
        <translation type="vanished">Nutzerverzeichnis</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="308"/>
        <source>Alt+Home</source>
        <translation>Alt+Pos1</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="424"/>
        <source>Reload</source>
        <translation>Neu laden</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="320"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="90"/>
        <source>Focus with Ctrl+I</source>
        <translation>Mit Strg+I fokussieren</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="178"/>
        <source>&amp;Toolbars</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="185"/>
        <source>Path &amp;Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="305"/>
        <source>&amp;Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="317"/>
        <source>&amp;Reload</source>
        <translation>Neu &amp;laden</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="329"/>
        <source>Go</source>
        <translation>Los</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="338"/>
        <source>Quit</source>
        <translation>Verlassen</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="347"/>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="359"/>
        <source>New Window</source>
        <translation>Neues Fenster</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="362"/>
        <source>Ctrl+N</source>
        <translation>Strg+N</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="370"/>
        <source>Show &amp;Hidden</source>
        <translation>&amp;Versteckte anzeigen</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="373"/>
        <source>Ctrl+H</source>
        <translation>Strg+H</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="382"/>
        <source>&amp;Computer</source>
        <translation>&amp;Geräte</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="391"/>
        <source>&amp;Trash</source>
        <translation>&amp;Papierkorb</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="396"/>
        <source>&amp;Network</source>
        <translation>&amp;Netzwerk</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="405"/>
        <source>&amp;Desktop</source>
        <translation>Schreib&amp;tisch</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="414"/>
        <source>&amp;Add to Bookmarks</source>
        <translation>Zu Lesezeichen &amp;hinzufügen</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="419"/>
        <source>&amp;Applications</source>
        <translation>&amp;Anwendungen</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="468"/>
        <source>Ctrl+X</source>
        <translation>Strg+X</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="477"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopieren</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="480"/>
        <source>Ctrl+C</source>
        <translation>Strg+C</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="489"/>
        <source>&amp;Paste</source>
        <translation>E&amp;infügen</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="492"/>
        <source>Ctrl+V</source>
        <translation>Strg+V</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="497"/>
        <source>Select &amp;All</source>
        <translation>&amp;Alles markieren</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="505"/>
        <source>Pr&amp;eferences</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="513"/>
        <source>&amp;Ascending</source>
        <translation>&amp;Aufsteigend</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="521"/>
        <source>&amp;Descending</source>
        <translation>A&amp;bsteigend</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="529"/>
        <source>&amp;By File Name</source>
        <translation>Nach &amp;Namen</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="537"/>
        <source>By &amp;Modification Time</source>
        <translation>Nach &amp;Zeitpunkt von Modifikationen</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="545"/>
        <source>By File &amp;Type</source>
        <translation>Nach Datei&amp;typ</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="553"/>
        <source>By &amp;Owner</source>
        <translation>Nach &amp;Eigentümer</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="561"/>
        <source>&amp;Folder First</source>
        <translation>&amp;Verzeichnisse zuerst</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="569"/>
        <source>&amp;Preserve sorting for this folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="619"/>
        <source>&amp;Invert Selection</source>
        <translation>Auswahl &amp;umkehren</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="628"/>
        <source>&amp;Delete</source>
        <translation>&amp;Löschen</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="636"/>
        <source>&amp;Rename</source>
        <translation>Um&amp;benennen</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="668"/>
        <source>&amp;Case Sensitive</source>
        <translation>Groß- und &amp;Kleinbuchstaben berücksichtigen</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="676"/>
        <source>By File &amp;Size</source>
        <translation>Nach Datei&amp;größe</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="681"/>
        <source>&amp;Close Window</source>
        <translation>Fe&amp;nster schließen</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="684"/>
        <source>Ctrl+Q</source>
        <translation>Strg+Q</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="747"/>
        <source>&amp;Filter</source>
        <translation>&amp;Filter</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="750"/>
        <source>Ctrl+B</source>
        <translation>Strg+B</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="759"/>
        <source>Close &amp;previous tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="768"/>
        <source>Close &amp;next tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="807"/>
        <source>&amp;Preserve Settings for This Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="812"/>
        <source>Connect to &amp;Server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="820"/>
        <source>&amp;Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="828"/>
        <source>&amp;Path Buttons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close &amp;left tabs</source>
        <translation type="vanished">Tabs &amp;links vom aktiven schließen</translation>
    </message>
    <message>
        <source>Close &amp;right tabs</source>
        <translation type="vanished">Tabs &amp;rechts vom aktiven schließen</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="773"/>
        <source>Close &amp;other tabs</source>
        <translation>Alle Tabs außer dem &amp;aktiven schließen</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="781"/>
        <source>&amp;Menu bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="784"/>
        <source>Menu bar</source>
        <translation>Menüleiste</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="787"/>
        <source>Ctrl+M</source>
        <translation>Strg+M</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="796"/>
        <location filename="../../main-win.ui" line="799"/>
        <source>Menu</source>
        <translation>Menü</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="500"/>
        <source>Ctrl+A</source>
        <translation>Strg+A</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="290"/>
        <source>Go &amp;Up</source>
        <translation>&amp;Übergeordneter Ordner</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="356"/>
        <source>&amp;New Window</source>
        <translation>Neues &amp;Fenster</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="432"/>
        <source>&amp;Icon View</source>
        <translation>&amp;Symbolansicht</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="440"/>
        <source>&amp;Compact View</source>
        <translation>&amp;Listenansicht</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="448"/>
        <source>&amp;Detailed List</source>
        <translation>&amp;Detailansicht</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="456"/>
        <source>&amp;Thumbnail View</source>
        <translation>&amp;Miniaturansicht</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="465"/>
        <source>Cu&amp;t</source>
        <translation>&amp;Ausschneiden</translation>
    </message>
    <message>
        <source>Ascending</source>
        <translation type="vanished">Aufsteigend</translation>
    </message>
    <message>
        <source>Descending</source>
        <translation type="vanished">Absteigend</translation>
    </message>
    <message>
        <source>By File Name</source>
        <translation type="vanished">Nach Name</translation>
    </message>
    <message>
        <source>By Modification Time</source>
        <translation type="vanished">Nach Änderungsdatum</translation>
    </message>
    <message>
        <source>By File Type</source>
        <translation type="vanished">Nach Dateityp</translation>
    </message>
    <message>
        <source>By Owner</source>
        <translation type="vanished">Nach Besitzer</translation>
    </message>
    <message>
        <source>Folder First</source>
        <translation type="vanished">Ordner zuerst</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="578"/>
        <source>New &amp;Tab</source>
        <translation>Neuer &amp;Tab</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="581"/>
        <source>New Tab</source>
        <translation>Neuer Tab</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="584"/>
        <source>Ctrl+T</source>
        <translation>Strg+T</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="593"/>
        <source>Go &amp;Back</source>
        <translation>&amp;Zurück</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="596"/>
        <source>Go Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="599"/>
        <source>Alt+Left</source>
        <translation>Alt+Pfeil links</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="608"/>
        <source>Go &amp;Forward</source>
        <translation>&amp;Vorwärts</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="611"/>
        <source>Go Forward</source>
        <translation>Vorwärts</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="614"/>
        <source>Alt+Right</source>
        <translation>Alt+Pfeil rechts</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="631"/>
        <source>Del</source>
        <translation>Entf</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="639"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="644"/>
        <source>C&amp;lose Tab</source>
        <translation>Tab &amp;schließen</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="652"/>
        <source>File &amp;Properties</source>
        <translation>&amp;Dateieigenschaften</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="660"/>
        <source>&amp;Folder Properties</source>
        <translation>&amp;Eigenschaften des aktuellen Ordners</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation type="vanished">Ordner</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="719"/>
        <source>Ctrl+Shift+N</source>
        <translation>Strg+Umschalt+N</translation>
    </message>
    <message>
        <source>Blank File</source>
        <translation type="vanished">Leere Datei</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="731"/>
        <source>Ctrl+Alt+N</source>
        <translation>Strg+Alt+N</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="124"/>
        <source>C&amp;reate New</source>
        <translation>Neu e&amp;rstellen</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="152"/>
        <source>&amp;Sorting</source>
        <translation>S&amp;ortierung</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="261"/>
        <source>Main Toolbar</source>
        <translation>Hauptwerkzeugleiste</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="647"/>
        <source>Ctrl+W</source>
        <translation>Strg+W</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="655"/>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Case Sensitive</source>
        <translation type="vanished">Groß-/Kleinschreibung beachten</translation>
    </message>
    <message>
        <source>By File Size</source>
        <translation type="vanished">Nach Dateigröße</translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation type="vanished">Fenster schließen</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="689"/>
        <source>Edit Bookmarks</source>
        <translation>Lesezeichen bearbeiten</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="694"/>
        <source>Open &amp;Terminal</source>
        <translation>&amp;Terminal öffnen</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="697"/>
        <source>F4</source>
        <translation>F4</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="702"/>
        <source>Open as &amp;Root</source>
        <translation>Als &amp;Root öffnen</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="707"/>
        <source>&amp;Edit Bookmarks</source>
        <translation>&amp;Lesezeichen bearbeiten</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="716"/>
        <source>&amp;Folder</source>
        <translation>&amp;Ordner</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="728"/>
        <source>&amp;Blank File</source>
        <translation>Leere &amp;Datei</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="736"/>
        <source>&amp;Find Files</source>
        <translation>&amp;Dateien suchen</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="739"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="93"/>
        <source>Filter by string...</source>
        <translation>Nach Zeichenketten filtern...</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="120"/>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="142"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="148"/>
        <location filename="../../main-win.ui" line="168"/>
        <source>&amp;View</source>
        <translation>&amp;Ansicht</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="202"/>
        <source>&amp;Edit</source>
        <translation>&amp;Bearbeiten</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="217"/>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Lesezeichen</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="224"/>
        <source>&amp;Go</source>
        <translation>&amp;Gehe zu</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="241"/>
        <source>&amp;Tool</source>
        <translation>&amp;Werkzeuge</translation>
    </message>
</context>
<context>
    <name>PCManFM::Application</name>
    <message>
        <location filename="../../application.cpp" line="170"/>
        <source>Name of configuration profile</source>
        <translation>Name des Konfigurationsprofils</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="170"/>
        <source>PROFILE</source>
        <translation>PROFIL</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="173"/>
        <source>Run PCManFM as a daemon</source>
        <translation>PCManFM als Daemon starten</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="176"/>
        <source>Quit PCManFM</source>
        <translation>PCManFM beenden</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="179"/>
        <source>Launch desktop manager</source>
        <translation>Verwaltung der Arbeitsfläche starten</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="182"/>
        <source>Turn off desktop manager if it&apos;s running</source>
        <translation>Verwaltung der Arbeitsfläche beenden, falls aktiv</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="185"/>
        <source>Open desktop preference dialog on the page with the specified name</source>
        <translation>Einstellungsdialog der Arbeitsfläche mit dem angegebenen Tab öffnen</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="185"/>
        <location filename="../../application.cpp" line="200"/>
        <source>NAME</source>
        <translation>NAME</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="188"/>
        <source>Open new window</source>
        <translation>Neues Fenster öffnen</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="191"/>
        <source>Open Find Files utility</source>
        <translation>Dateisuche öffnen</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="194"/>
        <source>Set desktop wallpaper from image FILE</source>
        <translation>Angegebene DATEI als Hintergrundbild einstellen</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="194"/>
        <source>FILE</source>
        <translation>DATEI</translation>
    </message>
    <message>
        <source>Set mode of desktop wallpaper. MODE=(color|stretch|fit|center|tile)</source>
        <translation type="vanished">Hintergrundbildmodus einstellen. MODUS=(color|stretch|fit|center|tile)</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="197"/>
        <source>MODE</source>
        <translation>MODUS</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="197"/>
        <source>Set mode of desktop wallpaper. MODE=(%1)</source>
        <translation>Modus des Hintergrundbildes einstellen. MODE=(%1)</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="200"/>
        <source>Open Preferences dialog on the page with the specified name</source>
        <translation>Einstellungsdialog auf dem angegebenen Tab öffnen</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="203"/>
        <source>Files or directories to open</source>
        <translation>Zu öfnende Dateien oder Ordner</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="203"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[DATEI1, DATEI2, ...]</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="540"/>
        <location filename="../../application.cpp" line="545"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="545"/>
        <source>Terminal emulator is not set.</source>
        <translation>Es ist kein Terminalemulator eingestellt.</translation>
    </message>
</context>
<context>
    <name>PCManFM::AutoRunDialog</name>
    <message>
        <location filename="../../autorundialog.cpp" line="45"/>
        <source>Open in file manager</source>
        <translation>Öffnen in Dateimanager</translation>
    </message>
    <message>
        <location filename="../../autorundialog.cpp" line="136"/>
        <source>Removable Disk</source>
        <translation>Entfernbares Medium</translation>
    </message>
</context>
<context>
    <name>PCManFM::ConnectServerDialog</name>
    <message>
        <location filename="../../connectserverdialog.cpp" line="9"/>
        <source>SSH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connectserverdialog.cpp" line="10"/>
        <source>FTP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connectserverdialog.cpp" line="11"/>
        <source>WebDav</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connectserverdialog.cpp" line="12"/>
        <source>Secure WebDav</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connectserverdialog.cpp" line="13"/>
        <source>HTTP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connectserverdialog.cpp" line="14"/>
        <source>HTTPS</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopPreferencesDialog</name>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="52"/>
        <source>Fill with background color only</source>
        <translation>Nur mit Hintergrundfarbe füllen</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="53"/>
        <source>Stretch to fill the entire screen</source>
        <translation>Auf Bildschirmgröße bringen</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="54"/>
        <source>Stretch to fit the screen</source>
        <translation>In Bildschirm einpassen</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="55"/>
        <source>Center on the screen</source>
        <translation>Zentriert</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="56"/>
        <source>Tile the image to fill the entire screen</source>
        <translation>Nebeneinander</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="57"/>
        <source>Zoom the image to fill the entire screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="204"/>
        <source>Image Files</source>
        <translation>Bilddateien</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopWindow</name>
    <message>
        <location filename="../../desktopwindow.cpp" line="525"/>
        <source>Stic&amp;k to Current Position</source>
        <translation>Symbole &amp;fixieren</translation>
    </message>
    <message>
        <location filename="../../desktopwindow.cpp" line="547"/>
        <source>Desktop Preferences</source>
        <translation>Schreibtischeinstellungen</translation>
    </message>
</context>
<context>
    <name>PCManFM::MainWindow</name>
    <message>
        <location filename="../../mainwindow.cpp" line="264"/>
        <source>Clear text (Ctrl+K)</source>
        <translation>Text löschen (Strg+K)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="343"/>
        <source>Hide menu bar</source>
        <translation>Menüleiste verbergen</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="344"/>
        <source>This will hide the menu bar completely, use Ctrl+M to show it again.</source>
        <translation>Die Menüleiste wird vollständig verborgen. Sie kann mit der Tastenkombination Strg+M wieder aktiviert werden.</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="628"/>
        <source>Version: %1</source>
        <translation>Version: %1</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="1263"/>
        <source>&amp;Move to Trash</source>
        <translation>In den &amp;Papierkorb verschieben</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="1263"/>
        <source>&amp;Delete</source>
        <translation>&amp;Löschen</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="1332"/>
        <location filename="../../mainwindow.cpp" line="1340"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="1340"/>
        <source>Switch user command is not set.</source>
        <translation>Befehl, um den Benutzer zu wechseln, ist nicht eingestellt.</translation>
    </message>
</context>
<context>
    <name>PCManFM::PreferencesDialog</name>
    <message>
        <location filename="../../preferencesdialog.cpp" line="195"/>
        <source>Icon View</source>
        <translation>Symbolansicht</translation>
    </message>
    <message>
        <source>Compact Icon View</source>
        <translation type="vanished">Kleine Symbolansicht</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.cpp" line="196"/>
        <source>Compact View</source>
        <translation>Listenansicht</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.cpp" line="197"/>
        <source>Thumbnail View</source>
        <translation>Miniaturansicht</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.cpp" line="198"/>
        <source>Detailed List View</source>
        <translation>Detaillierte Listenansicht</translation>
    </message>
</context>
<context>
    <name>PCManFM::TabPage</name>
    <message>
        <location filename="../../tabpage.cpp" line="279"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../../tabpage.cpp" line="292"/>
        <source>Free space: %1 (Total: %2)</source>
        <translation>Freier Speicherplatz: %1 (Gesamt: %2)</translation>
    </message>
    <message numerus="yes">
        <location filename="../../tabpage.cpp" line="309"/>
        <source>%n item(s)</source>
        <translation>
            <numerusform>%n Objekt</numerusform>
            <numerusform>%n Objekte</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../tabpage.cpp" line="311"/>
        <source> (%n hidden)</source>
        <translation>
            <numerusform>(%n versteckt)</numerusform>
            <numerusform>(%n versteckt)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../tabpage.cpp" line="485"/>
        <source>%n item(s) selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 item(s) selected</source>
        <translation type="vanished">%1 Objekte ausgewählt</translation>
    </message>
</context>
<context>
    <name>PCManFM::View</name>
    <message>
        <location filename="../../view.cpp" line="102"/>
        <source>Open in New T&amp;ab</source>
        <translation>Öffnen in neuem &amp;Tab</translation>
    </message>
    <message>
        <location filename="../../view.cpp" line="106"/>
        <source>Open in New Win&amp;dow</source>
        <translation>Öffnen in neuem &amp;Fenster</translation>
    </message>
    <message>
        <location filename="../../view.cpp" line="114"/>
        <source>Open in Termina&amp;l</source>
        <translation>Öffnen in &amp;Terminal</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../preferences.ui" line="14"/>
        <source>Preferences</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="45"/>
        <source>User Interface</source>
        <translation>Benutzeroberfläche</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="35"/>
        <source>Behavior</source>
        <translation>Verhalten</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="50"/>
        <location filename="../../preferences.ui" line="643"/>
        <source>Thumbnail</source>
        <translation>Vorschaubild</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="55"/>
        <source>Volume</source>
        <translation>Datenträger</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="60"/>
        <source>Advanced</source>
        <translation>Erweitert</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="220"/>
        <source>Icons</source>
        <translation>Symbole</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="252"/>
        <source>Size of big icons:</source>
        <translation>Größe für große Symbole:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="269"/>
        <source>Size of small icons:</source>
        <translation>Größe für kleine Symbole:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="286"/>
        <source>Size of thumbnails:</source>
        <translation>Größe von Vorschaubildern:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="300"/>
        <source>Size of side pane icons:</source>
        <translation>Größe der Symbole in der Seitenleiste:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="232"/>
        <source>Icon theme:</source>
        <translation>Symbolthema:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="456"/>
        <source>Window</source>
        <translation>Fenster</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="501"/>
        <source>Default width of new windows:</source>
        <translation>Breite für neue Fenster:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="515"/>
        <source>Default height of new windows:</source>
        <translation>Höhe für neue Fenster:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="469"/>
        <source>Always show the tab bar</source>
        <translation>Tableiste immer anzeigen</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="487"/>
        <source>Show &apos;Close&apos; buttons on tabs	</source>
        <translation>&apos;Schließen&apos;-Knopf an Tabs zeigen</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="494"/>
        <source>Remember the size of the last closed window</source>
        <translation>Größe des zuletzt geschlossenen Fensters merken</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="81"/>
        <source>Browsing</source>
        <translation>Durchstöbern</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="90"/>
        <source>Open files with single click</source>
        <translation>Einfacher Klick zum Öffnen von Dateien</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="100"/>
        <source>Delay of auto-selection in single click mode (0 to disable)</source>
        <translation>Wartezeit für die automatische Auswahl im Einzelklickmodus (0 zum Abschalten)</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="107"/>
        <source>Default view mode:</source>
        <translation>Standardansicht:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="120"/>
        <source> sec</source>
        <translation> sec</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="159"/>
        <source>File Operations</source>
        <translation>Handhabung von Dateien</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="165"/>
        <source>Confirm before deleting files</source>
        <translation>Löschen von Dateien bestätigen</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="172"/>
        <source>Move deleted files to &quot;trash bin&quot; instead of erasing from disk.</source>
        <translation>Gelöschte Dateien in den &quot;Papierkorb&quot; verschieben anstatt sie von der Festplatte zu löschen.</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="676"/>
        <source>Show thumbnails of files</source>
        <translation>Vorschaubilder von Dateien anzeigen</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="666"/>
        <source>Only show thumbnails for local files</source>
        <translation>Vorschaubilder nur für lokale Dateien anzeigen</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="40"/>
        <source>Display</source>
        <translation>Anzeige</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="130"/>
        <source>Bookmarks:</source>
        <translation>Lesezeichen:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="138"/>
        <source>Open in current tab</source>
        <translation>Öffnen in aktuellem Tab</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="143"/>
        <source>Open in new tab</source>
        <translation>Öffnen in neuem Tab</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="148"/>
        <source>Open in new window</source>
        <translation>Öffnen in neuem Fenster</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="179"/>
        <source>Erase files on removable media instead of &quot;trash can&quot; creation</source>
        <translation>Dateien auf Wechseldatenträgern löschen anstatt sie in den Papierkorb zu verschieben</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="186"/>
        <source>Confirm before moving files into &quot;trash can&quot;</source>
        <translation>Bestätigung vor Verschieben in den Papierkorb</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="193"/>
        <source>Don&apos;t ask options on launch executable file</source>
        <translation>Beim Starten ausführbarer Dateien keine Optionen hierzu erfragen</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="249"/>
        <location filename="../../preferences.ui" line="259"/>
        <source>Used by Icon View</source>
        <translation>Wird in der Symbolansicht verwendet</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="266"/>
        <location filename="../../preferences.ui" line="276"/>
        <source>Used by Compact View and Detailed List View</source>
        <translation>Wird in der Listen- und detaillierten Listenansicht verwendet</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="283"/>
        <location filename="../../preferences.ui" line="293"/>
        <source>Used by Thumbnail View</source>
        <translation>Wird in der Miniaturansicht verwendet</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="313"/>
        <source>User interface</source>
        <translation>Benutzeroberfläche</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="326"/>
        <source>Treat backup files as hidden</source>
        <translation>Sicherungsdateien wie versteckte handhaben</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="336"/>
        <source>Always show full file names</source>
        <translation>Dateinamen immer vollständig anzeigen</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="346"/>
        <source>Show icons of hidden files shadowed</source>
        <translation>Icons versteckter Dateien schattiert anzeigen</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="369"/>
        <source>Minimum item margins in icon view:</source>
        <translation>Minimaler Rand der Objekte in Symbolansicht:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="376"/>
        <source>3 px by default.</source>
        <translation>Standardwert 3 px.</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="379"/>
        <location filename="../../preferences.ui" line="403"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="392"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="399"/>
        <source>3 px by default.
A space is also reserved for 3 lines of text.</source>
        <translation>Standardwert 3 px.
Zusätzlich wird ein 3 Textzeilen entsprechender Abstand freigehalten.</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="416"/>
        <source>Lock</source>
        <translation>Sperren</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="465"/>
        <source>When unchecked, the tab bar will be shown
only if there are more than one tab.</source>
        <translation>Bei Deaktivierung wird die Leiste der Reiter (Tabs) nur angezeigt,
wenn mehr als einer geöffnet ist.</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="476"/>
        <source>If unchecked, the tab bar will be positioned only
above the folder-view and not above the left pane.</source>
        <translation>Bei Deaktivierung wird die Tab-Leiste nur über dem rechten Feld
mit der eigentlichen Verzeichnis- und Dateiansicht angezeigt und nicht
über die linke Spalte ausgedehnt.</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="480"/>
        <source>Fullwidth tab bar</source>
        <translation>Tab-Leiste über gesamte Fensterbreite ausdehnen</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="532"/>
        <source>Show in places</source>
        <translation>Unter &quot;Orte&quot; anzeigen</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="539"/>
        <source>Home</source>
        <translation>Nutzerverzeichnis</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="552"/>
        <source>Desktop</source>
        <translation>Schreibtisch</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="565"/>
        <source>Trash can</source>
        <translation>Papierkorb</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="578"/>
        <source>Computer</source>
        <translation>Rechner</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="591"/>
        <source>Applications</source>
        <translation>Anwendungen</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="599"/>
        <source>Devices</source>
        <translation>Geräte</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="607"/>
        <source>Network</source>
        <translation>Netzwerk</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="649"/>
        <source>Do not generate thumbnails for image files exceeding this size:</source>
        <translation>Keine Vorschaubilder erzeugen für Dateien größer als:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="656"/>
        <source> KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="673"/>
        <source>Needs ffmpegthumbnailer</source>
        <translation>Benötigt ffmpegthumbnailer</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="703"/>
        <source>Auto Mount</source>
        <translation>Automatisches Einbinden</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="709"/>
        <source>Mount mountable volumes automatically on program startup</source>
        <translation>Datenträger bei Programmstart automatisch einhängen</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="716"/>
        <source>Mount removable media automatically when they are inserted</source>
        <translation>Wechseldatenträger automatisch beim Einlegen einbinden</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="723"/>
        <source>Show available options for removable media when they are inserted</source>
        <translation>Verfügbare Optionen für Wechseldatenträger beim Einlegen anzeigen</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="733"/>
        <source>When removable medium unmounted:</source>
        <translation>Wenn Wechseldatenträger entfernt werden:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="739"/>
        <source>Close &amp;tab containing removable medium</source>
        <translation>Den Rei&amp;ter des Wechseldatenträgers schließen</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="746"/>
        <source>Chan&amp;ge folder in the tab to home folder</source>
        <translation>Im Tab des Wechsledatenträgers das Nutze&amp;rverzeichnis anzeigen</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="789"/>
        <source>Switch &amp;user command:</source>
        <translation>Befehl zum N&amp;utzerwechsel:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="813"/>
        <source>Archiver in&amp;tegration:</source>
        <translation>Archivverwal&amp;tung:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="836"/>
        <source>Templates</source>
        <translation>Vorlagen</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="842"/>
        <source>Show only user defined templates in menu</source>
        <translation>Ausschließlich benutzerdefinierte im Menü anzeigen</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="849"/>
        <source>Show only one template for each MIME type</source>
        <translation>Nur eine Vorlage pro MIME-Typ anzeigen</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="856"/>
        <source>Run default application after creation from template</source>
        <translation>Aus Vorlagen erstellte Dokumente in Standardanwendung öffnen</translation>
    </message>
    <message>
        <source>Close tab containing removable medium</source>
        <translation type="vanished">Schließe Tab mit Wechseldatenträger</translation>
    </message>
    <message>
        <source>Change folder in the tab to home folder</source>
        <translation type="vanished">Ändere Ordner im Tab zum Persönlichen Ordner</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="773"/>
        <source>Programs</source>
        <translation>Programme</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="782"/>
        <source>Terminal emulator:</source>
        <translation>Terminalemulator:</translation>
    </message>
    <message>
        <source>Switch user command:</source>
        <translation type="vanished">Befehl für Benutzerwechsel:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="802"/>
        <source>Examples: &quot;xterm -e %s&quot; for terminal or &quot;gksu %s&quot; for switching user.
%s = the command line you want to execute with terminal or su.</source>
        <translation>Beispiele:&quot;xterm -e %s&quot; für Terminal oder &quot;gksu %s&quot; für Benutzerwechsel.
%s = das Kommando, welches in einem Terminal oder als Root ausgeführt werden soll.</translation>
    </message>
    <message>
        <source>Archiver integration:</source>
        <translation type="vanished">Archivmanagerintegration:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="319"/>
        <source>Use SI decimal prefixes instead of IEC binary prefixes</source>
        <translation>SI-Dezimalpräfixe anstatt IEC-Binärpräfixe verwenden</translation>
    </message>
</context>
</TS>
